{+--------------------------------------------------------------------------+
 | Unit:        InspGrid
 | Created:     9.97
 | Author:      Martin Waldenburg
 | Copyright    1997, all rights reserved.
 | Description: A very ObjectInspector like grid.
 | Version:     1.0
 | Status:      FreeWare
 | It's provided as is, without a warranty of any kind.
 | You use it at your own risc.
 | E-Mail me at Martin.Waldenburg@t-online.de
 +--------------------------------------------------------------------------+}
unit InspGrid;


interface

uses
  SysUtils,
  Windows,
  Messages,
  Classes,
  Graphics,
  Controls,
  StdCtrls,
  ExtCtrls,
  Forms,
  Grids,
  Menus;

type
  TInspectGrid = class;

  TGridSplit = class(TPanel)
  private
  protected
    procedure WMMove(var Msg: TWMMove); message WM_Move;
    procedure WMLButtonDown(var Message: TWMLButtonDown); message WM_LBUTTONDOWN;
    procedure WMLButtonUp(var Message: TWMLButtonUp); message WM_LBUTTONUP;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  published
    property Visible;
    property Height default 200;
    property Width default 2;
  end;

  TInspectGrid = class(TStringGrid)
  private
    fDummy:Byte;
    function GetOptions:TGridOptions;
    procedure SetOptions(value:TGridOptions);
  protected
  public
    GridSplit1: TGridSplit;
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    procedure ResizeColums;
  published
    property GridHeight;
    property Options:TGridOptions read GetOptions write SetOptions;
    property ColCount:Byte read fDummy;
    property FixedColor:Byte read fDummy;
    property FixedCols:Byte read fDummy;
    property FixedRows:Byte read fDummy;
  end;

var
  InspectGrid: TInspectGrid;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('mw', [TInspectGrid]);
end;  { Register }

destructor TGridSplit.Destroy;
begin
  inherited Destroy;
end;  { Destroy }

constructor TGridSplit.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  Width := 2;
  Left:= 1;
  BevelOuter:= bvNone;
  BevelInner:= bvLowered;
  Cursor:= crHSplit;
  Color:= clBtnFace;
  ControlStyle := ControlStyle - [csAcceptsControls, csSetCaption];
end;  { Create }

procedure TGridSplit.WMMove(var Msg: TWMMove);
var
  LocalBoundsRect: TRect;
begin
  if not assigned(Parent) then exit;
  if csLoading in ComponentState then exit;
  LocalBoundsRect:= BoundsRect;
  with LocalBoundsRect Do
  begin
     Top := 0;
  end;
  BoundsRect:= LocalBoundsRect;
  (Owner as TInspectGrid).ResizeColums;
end;   { WMMove }

procedure TGridSplit.WMLButtonDown(var Message: TWMLButtonDown);
begin
  ReleaseCapture;
  SendMessage(TWinControl(self).Handle, WM_SysCommand, $F012, 0);
end;

procedure TGridSplit.WMLButtonUp(var Message: TWMLButtonUp);
begin

end;

constructor TInspectGrid.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  Width:= 132;
  Height:= 204;
  Color:= clBtnFace;
  inherited ColCount:= 2;
  inherited FixedCols:= 0;
  inherited FixedRows:= 0;
  DefaultColWidth:= 90;
  DefaultRowHeight:= 18;
  RowCount:= 20;
  ScrollBars:= ssVertical;

  GridSplit1 := TGridSplit.Create(Self);
  GridSplit1.Parent := Self;
  with GridSplit1 do
  begin
    if not Assigned(GridSplit1) then exit;
    Left:= 91;
    Top:= 0;
    Width:= 2;
    Height:= 200;
    Cursor:= crHSplit;
    BevelInner:= bvLowered;
    BevelOuter:= bvNone;
  end;
end;  { Create }

destructor TInspectGrid.Destroy;
begin
  inherited Destroy;
end;  { Destroy }

function TInspectGrid.GetOptions:TGridOptions;
begin
  GetOptions:= inherited Options;
end;   { GetOptions }

procedure TInspectGrid.SetOptions(value:TGridOptions);
begin
  inherited Options:= Value - [goFixedVertLine, goVertLine];
end;   { SetOptions }

procedure TInspectGrid.ResizeColums;
begin
  if ClientWidth - GridSplit1.Left < 50 then
    GridSplit1.Left:= ClientWidth - 50;
  if GridSplit1.Left < 50 then GridSplit1.Left:= 50;
  ColWidths[0]:= GridSplit1.Left +1;
  ColWidths[1]:= ClientWidth - ColWidths[0];
  GridSplit1.Height:= GridHeight;
end;  { ResizeColums }



end.
